# -*- coding: utf-8 -*-
"""List of current available base pairs in Bitfinex."""
from typing import List

quote_currency: List[str] = [
    'USD',
    'UST',
    'EUR',
    'CNHT',
    'GBP',
    'JPY',
    'DAI',
    'BTC',
    'EOS',
    'ETH',
    'XCH',
    'USTF0',
]
